# Enterprise API

Enterprise deployment utilities for health checks and configuration.

## Health Checks

::: orxaq.enterprise.health.HealthChecker

### Probe Types

| Probe | Path | Description |
|-------|------|-------------|
| Liveness | `/health` | Basic process health |
| Readiness | `/ready` | Ready to accept traffic |
| Deep | `/health/deep` | All subsystem checks |

## Configuration

::: orxaq.enterprise.config.EnterpriseConfig

### Environment Variables

| Variable | Default | Description |
|----------|---------|-------------|
| `ORXAQ_HOST` | `0.0.0.0` | Bind address |
| `ORXAQ_PORT` | `8741` | Server port |
| `ORXAQ_WORKERS` | `1` | Worker processes |
| `ORXAQ_CORS_ORIGINS` | `*` | Allowed CORS origins |
| `ORXAQ_AUTH_ENABLED` | `false` | Enable authentication |
| `ORXAQ_LOG_LEVEL` | `INFO` | Logging level |
| `ORXAQ_METRICS_ENABLED` | `false` | Enable metrics endpoint |
| `ORXAQ_DATA_DIR` | `data` | Data directory path |
| `ORXAQ_PLUGIN_DIR` | `plugins` | Plugin directory path |
